==> sk-2.32.1.zip: sk/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '%Y-%m-%d %H:%M';
L10n::$locales['_Jan'] = '_Jan';
L10n::$locales['_Feb'] = '_Feb';
L10n::$locales['_Mar'] = '_Mar';
L10n::$locales['_Apr'] = '_apr';
L10n::$locales['_May'] = '_Smieť';
L10n::$locales['_Jun'] = '_jún';
L10n::$locales['_Jul'] = '_Júl';
L10n::$locales['_Aug'] = '_Aug';
L10n::$locales['_Sep'] = '_Sept';
L10n::$locales['_Oct'] = '_Okt';
L10n::$locales['_Nov'] = '_nov';
L10n::$locales['_Dec'] = '_dec';
L10n::$locales['January'] = 'januára';
L10n::$locales['February'] = 'februára';
L10n::$locales['March'] = 'marca';
L10n::$locales['April'] = 'apríla';
L10n::$locales['May'] = 'Smieť';
L10n::$locales['June'] = 'júna';
L10n::$locales['July'] = 'júla';
L10n::$locales['August'] = 'augusta';
L10n::$locales['September'] = 'septembra';
L10n::$locales['October'] = 'októbra';
L10n::$locales['November'] = 'novembra';
L10n::$locales['December'] = 'December';
L10n::$locales['_Mon'] = '_Po';
L10n::$locales['_Tue'] = '_ut';
L10n::$locales['_Wed'] = '_Str';
L10n::$locales['_Thu'] = '_Št';
L10n::$locales['_Fri'] = '_Pia';
L10n::$locales['_Sat'] = '_So';
L10n::$locales['_Sun'] = '_Slnko';
L10n::$locales['Monday'] = 'pondelok';
L10n::$locales['Tuesday'] = 'utorok';
L10n::$locales['Wednesday'] = 'streda';
L10n::$locales['Thursday'] = 'štvrtok';
L10n::$locales['Friday'] = 'piatok';
L10n::$locales['Saturday'] = 'sobota';
L10n::$locales['Sunday'] = 'nedeľa';

==> sk-2.37-dev-r20260115.1158.zip: sk/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '%Y-%m-%d %H:%M';
L10n::$locales['_Jan'] = 'Jan';
L10n::$locales['_Feb'] = 'Feb';
L10n::$locales['_Mar'] = 'Mar';
L10n::$locales['_Apr'] = 'Apr';
L10n::$locales['_May'] = 'Smieť';
L10n::$locales['_Jun'] = 'Jún';
L10n::$locales['_Jul'] = 'Júl';
L10n::$locales['_Aug'] = 'Aug';
L10n::$locales['_Sep'] = 'Sept';
L10n::$locales['_Oct'] = 'Okt';
L10n::$locales['_Nov'] = 'Nov';
L10n::$locales['_Dec'] = 'Dec';
L10n::$locales['January'] = 'januára';
L10n::$locales['February'] = 'februára';
L10n::$locales['March'] = 'marca';
L10n::$locales['April'] = 'apríla';
L10n::$locales['May'] = 'Smieť';
L10n::$locales['June'] = 'júna';
L10n::$locales['July'] = 'júla';
L10n::$locales['August'] = 'augusta';
L10n::$locales['September'] = 'septembra';
L10n::$locales['October'] = 'októbra';
L10n::$locales['November'] = 'novembra';
L10n::$locales['December'] = 'December';
L10n::$locales['_Mon'] = 'Po';
L10n::$locales['_Tue'] = 'Ut';
L10n::$locales['_Wed'] = 'Str';
L10n::$locales['_Thu'] = 'Št';
L10n::$locales['_Fri'] = 'Pia';
L10n::$locales['_Sat'] = 'So';
L10n::$locales['_Sun'] = 'Slnko';
L10n::$locales['Monday'] = 'pondelok';
L10n::$locales['Tuesday'] = 'utorok';
L10n::$locales['Wednesday'] = 'streda';
L10n::$locales['Thursday'] = 'štvrtok';
L10n::$locales['Friday'] = 'piatok';
L10n::$locales['Saturday'] = 'sobota';
L10n::$locales['Sunday'] = 'nedeľa';
